==> Xarm-1.2.7.tar.gz: Xarm-1.2.7/include/Xarm/SeparatoG.h <==
/* $Id: SeparatoG.h,v 1.2 1997/04/07 15:33:22 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_SEPARATOG_H_)
#define _XARM_SEPARATOG_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Gadget.h>

class SeparatorGadgetClass : public GadgetClass {
 protected:
   SeparatorGadgetClass() {}
   virtual WidgetClass classPointer() { return xmSeparatorGadgetClass; }
   virtual _XtString className() { return (_XtString) "XmSeparatorGadget"; }
 public:
   /* resources */
   void margin(Dimension);
   Dimension margin();
   void orientation(unsigned char);
   unsigned char orientation();
   void separatorType(unsigned char);
   unsigned char separatorType();
};

class SeparatorGadget : public SeparatorGadgetClass {
 public:
   SeparatorGadget(Widget w_parent,
                   ArgList arglist = NULL,
                   Cardinal cnt = 0,
                   _XtString name = NULL);
   SeparatorGadget(_XtString name, Widget w_parent);
   SeparatorGadget(Widget w_parent, XarmArg &args, _XtString name);
};

#endif

==> Xarm-1.3.0.tar.gz: Xarm-1.3.0/include/Xarm/SeparatoG.h <==
/* $Id: SeparatoG.h,v 1.2 1997/04/07 15:33:22 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_SEPARATOG_H_)
#define _XARM_SEPARATOG_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Gadget.h>

class SeparatorGadgetClass : public GadgetClass {
 protected:
   SeparatorGadgetClass() {}
   virtual WidgetClass classPointer() { return xmSeparatorGadgetClass; }
   virtual _XtString className() { return (_XtString) "XmSeparatorGadget"; }
 public:
   /* resources */
   void margin(Dimension);
   Dimension margin() const;
   void orientation(unsigned char);
   unsigned char orientation() const;
   void separatorType(unsigned char);
   unsigned char separatorType() const;
};

class SeparatorGadget : public SeparatorGadgetClass {
 public:
   SeparatorGadget(Widget w_parent,
                   ArgList arglist = NULL,
                   Cardinal cnt = 0,
                   _XtString name = NULL);
   SeparatorGadget(_XtString name, Widget w_parent);
   SeparatorGadget(Widget w_parent, XarmArg &args, _XtString name);
};

#endif
